# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class PaymentInstallmentInline(admin.TabularInline):
    model = models.PaymentInstallment
    extra = 0
    fk_name = 'payment_form'
    fields = (
        'amount', 'days', 'end_month',
        'days_end_month', 'discount', 'fee'
    )


class PaymentFormAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('code', 'name',)
    advanced_search_fields = (
        ('status', 'name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
           'fields': ('code', 'name', 'description', 'fee', 'discount')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('pk', 'status', 'code', 'name', 'description', 'fee', 'discount', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    inlines = (PaymentInstallmentInline,)


class PaymentInstallmentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('code', 'name',)
    advanced_search_fields = (
        ('status', 'name__icontains',),
        ('payment_form__name__icontains',),
        ('days__gte', 'days__lte',),
        ('days_end_month__gte', 'days_end_month__lte',),
        ('end_month',),
    )
    list_filter = ('status', 'end_month',)
    fieldsets = (
        (_('general information'), {
           'fields': (
               'payment_form', 'code', 'name', 'description',
               'amount', 'days', 'end_month', 'discount', 'fee',
               'days_end_month',
           )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status', 'payment_form', 'code', 'name', 'amount',
        'days', 'end_month', 'days_end_month',
        'ordering'
    )
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('payment_form',)


admin.site.register(models.PaymentForm, PaymentFormAdmin)
admin.site.register(models.PaymentInstallment, PaymentInstallmentAdmin)
