# -*- coding: utf-8 -*-

from rest_framework import serializers

from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# PAYMENT FORM
class PaymentFormSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form'
        model = models.PaymentForm
        fields = '__all__'


class PaymentFormCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return PaymentFormSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_payment_payment_form_create'
        model = models.PaymentForm
        fields = '__all__'


class PaymentFormUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return PaymentFormSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_payment_payment_form_update'
        model = models.PaymentForm
        fields = '__all__'


class PaymentFormEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_payment_payment_form_enable'
        model = models.PaymentForm
        fields = '__all__'

    def to_representation(self, instance):
        return PaymentFormSerializer(instance, context=self.context).data


class PaymentFormDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_payment_payment_form_disable'
        model = models.PaymentForm
        fields = '__all__'

    def to_representation(self, instance):
        return PaymentFormSerializer(instance, context=self.context).data


# PAYMENT INSTALLMENT
class PaymentInstallmentSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_installment'
        model = models.PaymentInstallment
        fields = '__all__'


class PaymentInstallmentCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return PaymentInstallmentSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_payment_payment_installment_create'
        model = models.PaymentInstallment
        fields = '__all__'


class PaymentInstallmentUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return PaymentInstallmentSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_payment_payment_installment_update'
        model = models.PaymentInstallment
        fields = '__all__'


class PaymentInstallmentEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_payment_payment_installment_enable'
        model = models.PaymentInstallment
        fields = '__all__'

    def to_representation(self, instance):
        return PaymentInstallmentSerializer(instance, context=self.context).data


class PaymentInstallmentDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_payment_payment_installment_disable'
        model = models.PaymentInstallment
        fields = '__all__'

    def to_representation(self, instance):
        return PaymentInstallmentSerializer(instance, context=self.context).data
